==> qtjambi-network-debuginfo-windows-x64-5.15.18.jar: sources/QtJambiNetwork/QNetworkCookieJar_shell.h <==
#ifndef QNETWORKCOOKIEJAR_SHELL_H
#define QNETWORKCOOKIEJAR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtNetwork/qnetworkcookiejar.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtNetwork/qnetworkcookie.h>
#include "hashes.h"
#include <QtJambi/RegistryAPI>


class QNetworkCookieJar_shell : public QNetworkCookieJar, public QtJambiShellInterface
{
public:
    QNetworkCookieJar_shell(QObject* parent0 = nullptr);
    ~QNetworkCookieJar_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QList<QNetworkCookie> cookiesForUrl(const QUrl& url0) const override;
    void customEvent(QEvent* event0) override;
    bool deleteCookie(const QNetworkCookie& cookie0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool insertCookie(const QNetworkCookie& cookie0) override;
    bool setCookiesFromUrl(const QList<QNetworkCookie>& cookieList0, const QUrl& url1) override;
    void timerEvent(QTimerEvent* event0) override;
    bool updateCookie(const QNetworkCookie& cookie0) override;
    bool validateCookie(const QNetworkCookie& cookie0, const QUrl& url1) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QNetworkCookieJar_access : public QNetworkCookieJar
{
    jobject __qt_allCookies(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setAllCookies_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject cookieList0);
    jobject __qt_cookiesForUrl_cref_QUrl_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0) const;
    jboolean __qt_deleteCookie_cref_QNetworkCookie(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID cookie0);
    jboolean __qt_insertCookie_cref_QNetworkCookie(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID cookie0);
    jboolean __qt_setCookiesFromUrl_cref_QList_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject cookieList0, QtJambiNativeID url1);
    jboolean __qt_updateCookie_cref_QNetworkCookie(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID cookie0);
    jboolean __qt_validateCookie_cref_QNetworkCookie_cref_QUrl_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID cookie0, QtJambiNativeID url1) const;
};

#endif // QNETWORKCOOKIEJAR_SHELL_H

==> qtjambi-network-debuginfo-windows-x64-5.15.19.jar: sources/QtJambiNetwork/QNetworkCookieJar_shell.h <==
#ifndef QNETWORKCOOKIEJAR_SHELL_H
#define QNETWORKCOOKIEJAR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtNetwork/qnetworkcookiejar.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtNetwork/qnetworkcookie.h>
#include "hashes.h"
#include <QtJambi/RegistryAPI>


class QNetworkCookieJar_shell : public QNetworkCookieJar, public QtJambiShellInterface
{
public:
    QNetworkCookieJar_shell(QObject* parent0 = nullptr);
    ~QNetworkCookieJar_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QList<QNetworkCookie> cookiesForUrl(const QUrl& url0) const override;
    void customEvent(QEvent* event0) override;
    bool deleteCookie(const QNetworkCookie& cookie0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool insertCookie(const QNetworkCookie& cookie0) override;
    bool setCookiesFromUrl(const QList<QNetworkCookie>& cookieList0, const QUrl& url1) override;
    void timerEvent(QTimerEvent* event0) override;
    bool updateCookie(const QNetworkCookie& cookie0) override;
    bool validateCookie(const QNetworkCookie& cookie0, const QUrl& url1) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QNetworkCookieJar_access : public QNetworkCookieJar
{
    jobject __qt_allCookies_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setAllCookies_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject cookieList0);
    jobject __qt_cookiesForUrl_cref_QUrl_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0) const;
    jboolean __qt_deleteCookie_cref_QNetworkCookie(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID cookie0);
    jboolean __qt_insertCookie_cref_QNetworkCookie(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID cookie0);
    jboolean __qt_setCookiesFromUrl_cref_QList_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject cookieList0, QtJambiNativeID url1);
    jboolean __qt_updateCookie_cref_QNetworkCookie(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID cookie0);
    jboolean __qt_validateCookie_cref_QNetworkCookie_cref_QUrl_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID cookie0, QtJambiNativeID url1) const;
};

#endif // QNETWORKCOOKIEJAR_SHELL_H
